==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleCustomizationBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleCustomizationBuilder extends io.fabric8.openshift.api.model.operator.v1.ConsoleCustomizationFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConsoleCustomizationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.ConsoleCustomization,io.fabric8.openshift.api.model.operator.v1.ConsoleCustomizationBuilder>{
  public ConsoleCustomizationBuilder() {
    this(false);
  }
  public ConsoleCustomizationBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleCustomization(), validationEnabled);
  }
  public ConsoleCustomizationBuilder(io.fabric8.openshift.api.model.operator.v1.ConsoleCustomizationFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleCustomizationBuilder(io.fabric8.openshift.api.model.operator.v1.ConsoleCustomizationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleCustomization(), validationEnabled);
  }
  public ConsoleCustomizationBuilder(io.fabric8.openshift.api.model.operator.v1.ConsoleCustomizationFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ConsoleCustomization instance) {
    this(fluent, instance, false);
  }
  public ConsoleCustomizationBuilder(io.fabric8.openshift.api.model.operator.v1.ConsoleCustomizationFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ConsoleCustomization instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddPage(instance.getAddPage()); 
    fluent.withBrand(instance.getBrand()); 
    fluent.withCustomLogoFile(instance.getCustomLogoFile()); 
    fluent.withCustomProductName(instance.getCustomProductName()); 
    fluent.withDeveloperCatalog(instance.getDeveloperCatalog()); 
    fluent.withDocumentationBaseURL(instance.getDocumentationBaseURL()); 
    fluent.withProjectAccess(instance.getProjectAccess()); 
    fluent.withQuickStarts(instance.getQuickStarts()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleCustomizationBuilder(io.fabric8.openshift.api.model.operator.v1.ConsoleCustomization instance) {
    this(instance,false);
  }
  public ConsoleCustomizationBuilder(io.fabric8.openshift.api.model.operator.v1.ConsoleCustomization instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddPage(instance.getAddPage()); 
    this.withBrand(instance.getBrand()); 
    this.withCustomLogoFile(instance.getCustomLogoFile()); 
    this.withCustomProductName(instance.getCustomProductName()); 
    this.withDeveloperCatalog(instance.getDeveloperCatalog()); 
    this.withDocumentationBaseURL(instance.getDocumentationBaseURL()); 
    this.withProjectAccess(instance.getProjectAccess()); 
    this.withQuickStarts(instance.getQuickStarts()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.ConsoleCustomizationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.ConsoleCustomization build() {
    ConsoleCustomization buildable = new ConsoleCustomization(fluent.getAddPage(),fluent.getBrand(),fluent.getCustomLogoFile(),fluent.getCustomProductName(),fluent.getDeveloperCatalog(),fluent.getDocumentationBaseURL(),fluent.getProjectAccess(),fluent.getQuickStarts());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleCustomizationBuilder that = (ConsoleCustomizationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.2.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleCustomizationBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsoleCustomizationBuilder extends ConsoleCustomizationFluentImpl<ConsoleCustomizationBuilder> implements VisitableBuilder<ConsoleCustomization,ConsoleCustomizationBuilder>{
  public ConsoleCustomizationBuilder() {
    this(false);
  }
  public ConsoleCustomizationBuilder(Boolean validationEnabled) {
    this(new ConsoleCustomization(), validationEnabled);
  }
  public ConsoleCustomizationBuilder(ConsoleCustomizationFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleCustomizationBuilder(ConsoleCustomizationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsoleCustomization(), validationEnabled);
  }
  public ConsoleCustomizationBuilder(ConsoleCustomizationFluent<?> fluent,ConsoleCustomization instance) {
    this(fluent, instance, false);
  }
  public ConsoleCustomizationBuilder(ConsoleCustomizationFluent<?> fluent,ConsoleCustomization instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddPage(instance.getAddPage()); 
    fluent.withBrand(instance.getBrand()); 
    fluent.withCustomLogoFile(instance.getCustomLogoFile()); 
    fluent.withCustomProductName(instance.getCustomProductName()); 
    fluent.withDeveloperCatalog(instance.getDeveloperCatalog()); 
    fluent.withDocumentationBaseURL(instance.getDocumentationBaseURL()); 
    fluent.withProjectAccess(instance.getProjectAccess()); 
    fluent.withQuickStarts(instance.getQuickStarts()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleCustomizationBuilder(ConsoleCustomization instance) {
    this(instance,false);
  }
  public ConsoleCustomizationBuilder(ConsoleCustomization instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddPage(instance.getAddPage()); 
    this.withBrand(instance.getBrand()); 
    this.withCustomLogoFile(instance.getCustomLogoFile()); 
    this.withCustomProductName(instance.getCustomProductName()); 
    this.withDeveloperCatalog(instance.getDeveloperCatalog()); 
    this.withDocumentationBaseURL(instance.getDocumentationBaseURL()); 
    this.withProjectAccess(instance.getProjectAccess()); 
    this.withQuickStarts(instance.getQuickStarts()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConsoleCustomizationFluent<?> fluent;
  Boolean validationEnabled;
  public ConsoleCustomization build() {
    ConsoleCustomization buildable = new ConsoleCustomization(fluent.getAddPage(),fluent.getBrand(),fluent.getCustomLogoFile(),fluent.getCustomProductName(),fluent.getDeveloperCatalog(),fluent.getDocumentationBaseURL(),fluent.getProjectAccess(),fluent.getQuickStarts());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
